Lens

Struct Lens 

pub struct Lens<PO: Strong<S, T>, PI: Strong<A, B>, S, T, A, B>(pub Optic<PO, PI, S, T, A, B>);
A Lens is a type of Optic that focuses on a part A of a whole S, allowing both getting the part and setting it (which might change S to T and A to B).

Lenses are typically built from Strong profunctors. This Lens struct wraps an Optic.

Tuple Fields

0: Optic<PO, PI, S, T, A, B>

The underlying Optic representation of the lens.